/* mito_lib.h -- header for the file of procedures that read Galaxy
*  mitochondrial genotypes and coverage, as well as the names of individuals
*  that should be processed and which columns of the two gd_genotype files
*  contain their genotypes. (The column information actually names two
*  columns before the genotype, in case the SNP file is gd_snp format. The
*  resulting data structure has one entry per processed individual, giving
*  the SNPs and adequately covered intervals
*/

struct snp {
	int pos;
	struct snp *next;
};

struct covered {
	int b, e;
	struct covered *next;
};

// maximum number of individuals
#define MAX_INDIV 1000

struct individ {
	char *name;
	int snp_col, cov_col, start_cov;
	struct snp *snp, *last_snp;
	struct covered *cov, *last_cov;
} I[MAX_INDIV];

int nI, min_cov, ref_len, debug;

// record the name of an individual to be processed, or save the individual's
// columns numbers in the files giving SNPs or coverage information
void insert_indiv(char *argv);

// read the file of coverages
void get_covered(char *filename);

// read the file of genotypes
void get_snps(char *filename);

// put end-markers on the lists of snps and intervals once ref_len stabilizes
void sentinels();
